aboutsummaryrefslogtreecommitdiff
path: root/src/corelib/theme/mthemedaemon.cpp
diff options
context:
space:
mode:
authorHolger Schroeder <holger.schroeder.ext@basyskom.de>2010-04-24 23:42:43 +0200
committerTomas Junnonen <tomas.junnonen@nokia.com>2010-05-03 15:19:12 +0300
commitc8e8d90465783582f2deb948f614bc99d12c7728 (patch)
tree2089f112f17506e7232b245543ad4363d39b5927 /src/corelib/theme/mthemedaemon.cpp
parent1c16e591bde23c40bab63f304665e697ad278c28 (diff)
Changes: use X-MeeGoTouch-Metatheme in index.theme
RevBy: Armin Berres Details: We agreed upon X-MeeGoTouch-Metatheme as the type and section name for theme index files. This patch adapts libmeegotouch to it.
Diffstat (limited to 'src/corelib/theme/mthemedaemon.cpp')
-rw-r--r--src/corelib/theme/mthemedaemon.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/corelib/theme/mthemedaemon.cpp b/src/corelib/theme/mthemedaemon.cpp
index 456c728d..93dff0cf 100644
--- a/src/corelib/theme/mthemedaemon.cpp
+++ b/src/corelib/theme/mthemedaemon.cpp
@@ -209,14 +209,14 @@ const QSettings *themeFile(const QString &theme)
return NULL;
}
// step 3: we need to have X-MeegoTouch-Metatheme group in index.theme
// here we accept also the old X-DUI-Metatheme, because the old and new files
// are in the same directory. remove "X-DUI-Metatheme" when libdui 0.19 and
// duitheme with it is phased out.
if ( (!themeIndexFile->childGroups().contains(QString("X-DUI-Metatheme")))
- && (!themeIndexFile->childGroups().contains(QString("X-MeegoTouch-Metatheme"))) )
+ && (!themeIndexFile->childGroups().contains(QString("X-MeeGoTouch-Metatheme"))) )
{
delete themeIndexFile;
return NULL;
@@ -257,7 +257,7 @@ bool MThemeDaemon::activateTheme(const QString &newTheme, const QString &locale,
}
newThemeInheritanceChain.append(tmpTheme);
- QString parentTheme = themeIndexFile->value("X-MeegoTouch-Metatheme/X-Inherits", "").toString();
+ QString parentTheme = themeIndexFile->value("X-MeeGoTouch-Metatheme/X-Inherits", "").toString();
// remove when duitheme is phased out
if ( parentTheme.isEmpty() )
@@ -266,7 +266,7 @@ bool MThemeDaemon::activateTheme(const QString &newTheme, const QString &locale,
}
// end remove
- QStringList libraryNames = themeIndexFile->value("X-MeegoTouch-Metatheme/X-Libraries", "").toString().split(",", QString::SkipEmptyParts);
+ QStringList libraryNames = themeIndexFile->value("X-MeeGoTouch-Metatheme/X-Libraries", "").toString().split(",", QString::SkipEmptyParts);
// remove when duitheme is phased out
if ( libraryNames.isEmpty() )
@@ -209,14 +209,14 @@ const QSettings *themeFile(const QString &theme)
return NULL;
}
- // step 3: we need to have X-MeegoTouch-Metatheme group in index.theme
+ // step 3: we need to have X-MeeGoTouch-Metatheme group in index.theme
// here we accept also the old X-DUI-Metatheme, because the old and new files
// are in the same directory. remove "X-DUI-Metatheme" when libdui 0.19 and